Crate containers_image_proxy

Crate containers_image_proxy 

Run skopeo as a subprocess to fetch container images.

This allows fetching a container image manifest and layers in a streaming fashion.

More information: https://github.com/containers/skopeo/pull/1476

Re-exports

pub use transport::ContainersStorageRef;
pub use transport::ImageReference;
pub use transport::ImageReferenceError;
pub use transport::Transport;
pub use transport::TransportConversionError;
pub use ::oci_spec;

Modules

transport

Structs

BlobStream
A streaming blob reader and “driver” future.
ConvertedLayerInfo
BlobInfo collects known information about a blob
ImageProxy
Manage a child process proxy to fetch container images.
ImageProxyConfig
Configuration for the proxy.
OpenedImage
Opaque identifier for an image

Enums

BlobStreamSource
Error
Errors returned by this crate.
GetBlobError
Errors returned by get_raw_blob

Constants

RESERVED_FD_RANGE
File descriptor range which is reserved for passing data down into the proxy; avoid configuring the command to use files in this range. (Also, stdin is reserved)

Type Aliases

Result
The error type returned from this crate.